# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Any

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSlowLogStatisticResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSlowLogStatisticResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # AsyncResult<DBLogRecords<SlowLogStat>>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSlowLogStatisticResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSlowLogStatisticResponseBodyData(DaraModel):
    def __init__(
        self,
        data: main_models.DescribeSlowLogStatisticResponseBodyDataData = None,
        error_code: int = None,
        is_finish: bool = None,
        message: str = None,
        request_key: str = None,
        result_id: str = None,
        state: str = None,
        timestamp: int = None,
    ):
        self.data = data
        self.error_code = error_code
        self.is_finish = is_finish
        self.message = message
        self.request_key = request_key
        self.result_id = result_id
        self.state = state
        self.timestamp = timestamp

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.is_finish is not None:
            result['IsFinish'] = self.is_finish

        if self.message is not None:
            result['Message'] = self.message

        if self.request_key is not None:
            result['RequestKey'] = self.request_key

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        if self.state is not None:
            result['State'] = self.state

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('IsFinish') is not None:
            self.is_finish = m.get('IsFinish')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestKey') is not None:
            self.request_key = m.get('RequestKey')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class DescribeSlowLogStatisticResponseBodyDataData(DaraModel):
    def __init__(
        self,
        db_instance_id: int = None,
        db_instance_name: str = None,
        end_time: str = None,
        items_numbers: int = None,
        logs: List[main_models.DescribeSlowLogStatisticResponseBodyDataDataLogs] = None,
        max_records_per_page: int = None,
        node_id: str = None,
        page_numbers: int = None,
        start_time: str = None,
        total_records: int = None,
    ):
        self.db_instance_id = db_instance_id
        self.db_instance_name = db_instance_name
        self.end_time = end_time
        self.items_numbers = items_numbers
        self.logs = logs
        self.max_records_per_page = max_records_per_page
        self.node_id = node_id
        self.page_numbers = page_numbers
        self.start_time = start_time
        self.total_records = total_records

    def validate(self):
        if self.logs:
            for v1 in self.logs:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_instance_id is not None:
            result['DbInstanceId'] = self.db_instance_id

        if self.db_instance_name is not None:
            result['DbInstanceName'] = self.db_instance_name

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.items_numbers is not None:
            result['ItemsNumbers'] = self.items_numbers

        result['Logs'] = []
        if self.logs is not None:
            for k1 in self.logs:
                result['Logs'].append(k1.to_map() if k1 else None)

        if self.max_records_per_page is not None:
            result['MaxRecordsPerPage'] = self.max_records_per_page

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.page_numbers is not None:
            result['PageNumbers'] = self.page_numbers

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.total_records is not None:
            result['TotalRecords'] = self.total_records

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbInstanceId') is not None:
            self.db_instance_id = m.get('DbInstanceId')

        if m.get('DbInstanceName') is not None:
            self.db_instance_name = m.get('DbInstanceName')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('ItemsNumbers') is not None:
            self.items_numbers = m.get('ItemsNumbers')

        self.logs = []
        if m.get('Logs') is not None:
            for k1 in m.get('Logs'):
                temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataDataLogs()
                self.logs.append(temp_model.from_map(k1))

        if m.get('MaxRecordsPerPage') is not None:
            self.max_records_per_page = m.get('MaxRecordsPerPage')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PageNumbers') is not None:
            self.page_numbers = m.get('PageNumbers')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('TotalRecords') is not None:
            self.total_records = m.get('TotalRecords')

        return self

class DescribeSlowLogStatisticResponseBodyDataDataLogs(DaraModel):
    def __init__(
        self,
        account_name: str = None,
        avg_cputime: float = None,
        avg_cputime_seconds: float = None,
        avg_doc_examined: float = None,
        avg_frows: float = None,
        avg_iowrites: float = None,
        avg_keys_examined: float = None,
        avg_last_rows_count_affected: float = None,
        avg_lock_time: float = None,
        avg_lock_time_seconds: float = None,
        avg_logical_ioreads: float = None,
        avg_physical_ioreads: float = None,
        avg_query_time: float = None,
        avg_query_time_seconds: float = None,
        avg_request_size: float = None,
        avg_response_size: float = None,
        avg_return_num: float = None,
        avg_rows: float = None,
        avg_rows_count_affected: float = None,
        avg_rows_examined: float = None,
        avg_rows_sent: float = None,
        avg_rt: float = None,
        avg_scnt: float = None,
        cputime: float = None,
        cputime_seconds: float = None,
        client_ip: str = None,
        cmd: str = None,
        command: str = None,
        count: int = None,
        count_rate: float = None,
        dbname: str = None,
        database: str = None,
        db_id: str = None,
        db_instance_name: str = None,
        doc_examined: int = None,
        docs_examined: int = None,
        frows: int = None,
        histogram: main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram = None,
        host_address: str = None,
        host_ins_id: str = None,
        iowrites: int = None,
        ins_name: str = None,
        ins_role: str = None,
        keys_examined: int = None,
        last_rows_count_affected: int = None,
        lock_time: float = None,
        lock_time_seconds: float = None,
        logical_ioreads: int = None,
        max_cputime: float = None,
        max_cputime_seconds: float = None,
        max_doc_examined: int = None,
        max_frows: int = None,
        max_iowrites: int = None,
        max_keys_examined: int = None,
        max_last_rows_count_affected: int = None,
        max_lock_time: float = None,
        max_lock_time_seconds: float = None,
        max_logical_ioreads: int = None,
        max_physical_ioreads: int = None,
        max_query_time: float = None,
        max_query_time_seconds: float = None,
        max_request_size: float = None,
        max_response_size: float = None,
        max_return_num: int = None,
        max_rows: int = None,
        max_rows_count_affected: int = None,
        max_rows_examined: int = None,
        max_rows_sent: int = None,
        max_rt: float = None,
        max_scnt: int = None,
        namespace: str = None,
        node_type: str = None,
        op_type: str = None,
        origin_alias: str = None,
        physical_ioreads: int = None,
        psql: str = None,
        query_id: str = None,
        query_start_time: str = None,
        query_time: int = None,
        query_time_rate: float = None,
        query_time_seconds: float = None,
        return_item_numbers: str = None,
        return_num: int = None,
        rows: int = None,
        rows_count_affected: int = None,
        rows_examined: int = None,
        rows_sent: int = None,
        rule_id: str = None,
        sqltext: str = None,
        scheme: str = None,
        scnt: int = None,
        sql_id: str = None,
        sql_tag: main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag = None,
        sql_type: str = None,
        sub_instance_id: str = None,
        table_name: str = None,
        thread_id: str = None,
        timestamp: int = None,
        total_count: int = None,
        trend: List[main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsTrend] = None,
        user: str = None,
    ):
        self.account_name = account_name
        self.avg_cputime = avg_cputime
        self.avg_cputime_seconds = avg_cputime_seconds
        self.avg_doc_examined = avg_doc_examined
        self.avg_frows = avg_frows
        self.avg_iowrites = avg_iowrites
        self.avg_keys_examined = avg_keys_examined
        self.avg_last_rows_count_affected = avg_last_rows_count_affected
        self.avg_lock_time = avg_lock_time
        self.avg_lock_time_seconds = avg_lock_time_seconds
        self.avg_logical_ioreads = avg_logical_ioreads
        self.avg_physical_ioreads = avg_physical_ioreads
        self.avg_query_time = avg_query_time
        self.avg_query_time_seconds = avg_query_time_seconds
        self.avg_request_size = avg_request_size
        self.avg_response_size = avg_response_size
        self.avg_return_num = avg_return_num
        self.avg_rows = avg_rows
        self.avg_rows_count_affected = avg_rows_count_affected
        self.avg_rows_examined = avg_rows_examined
        self.avg_rows_sent = avg_rows_sent
        self.avg_rt = avg_rt
        self.avg_scnt = avg_scnt
        self.cputime = cputime
        self.cputime_seconds = cputime_seconds
        self.client_ip = client_ip
        self.cmd = cmd
        self.command = command
        self.count = count
        self.count_rate = count_rate
        self.dbname = dbname
        self.database = database
        self.db_id = db_id
        self.db_instance_name = db_instance_name
        self.doc_examined = doc_examined
        self.docs_examined = docs_examined
        self.frows = frows
        self.histogram = histogram
        self.host_address = host_address
        self.host_ins_id = host_ins_id
        self.iowrites = iowrites
        self.ins_name = ins_name
        self.ins_role = ins_role
        self.keys_examined = keys_examined
        self.last_rows_count_affected = last_rows_count_affected
        self.lock_time = lock_time
        self.lock_time_seconds = lock_time_seconds
        self.logical_ioreads = logical_ioreads
        self.max_cputime = max_cputime
        self.max_cputime_seconds = max_cputime_seconds
        self.max_doc_examined = max_doc_examined
        self.max_frows = max_frows
        self.max_iowrites = max_iowrites
        self.max_keys_examined = max_keys_examined
        self.max_last_rows_count_affected = max_last_rows_count_affected
        self.max_lock_time = max_lock_time
        self.max_lock_time_seconds = max_lock_time_seconds
        self.max_logical_ioreads = max_logical_ioreads
        self.max_physical_ioreads = max_physical_ioreads
        self.max_query_time = max_query_time
        self.max_query_time_seconds = max_query_time_seconds
        self.max_request_size = max_request_size
        self.max_response_size = max_response_size
        self.max_return_num = max_return_num
        self.max_rows = max_rows
        self.max_rows_count_affected = max_rows_count_affected
        self.max_rows_examined = max_rows_examined
        self.max_rows_sent = max_rows_sent
        self.max_rt = max_rt
        self.max_scnt = max_scnt
        self.namespace = namespace
        self.node_type = node_type
        self.op_type = op_type
        self.origin_alias = origin_alias
        self.physical_ioreads = physical_ioreads
        self.psql = psql
        self.query_id = query_id
        self.query_start_time = query_start_time
        self.query_time = query_time
        self.query_time_rate = query_time_rate
        self.query_time_seconds = query_time_seconds
        self.return_item_numbers = return_item_numbers
        self.return_num = return_num
        self.rows = rows
        self.rows_count_affected = rows_count_affected
        self.rows_examined = rows_examined
        self.rows_sent = rows_sent
        self.rule_id = rule_id
        self.sqltext = sqltext
        self.scheme = scheme
        self.scnt = scnt
        # SQL ID。
        self.sql_id = sql_id
        self.sql_tag = sql_tag
        self.sql_type = sql_type
        self.sub_instance_id = sub_instance_id
        self.table_name = table_name
        self.thread_id = thread_id
        self.timestamp = timestamp
        self.total_count = total_count
        self.trend = trend
        self.user = user

    def validate(self):
        if self.histogram:
            self.histogram.validate()
        if self.sql_tag:
            self.sql_tag.validate()
        if self.trend:
            for v1 in self.trend:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_name is not None:
            result['AccountName'] = self.account_name

        if self.avg_cputime is not None:
            result['AvgCPUTime'] = self.avg_cputime

        if self.avg_cputime_seconds is not None:
            result['AvgCPUTimeSeconds'] = self.avg_cputime_seconds

        if self.avg_doc_examined is not None:
            result['AvgDocExamined'] = self.avg_doc_examined

        if self.avg_frows is not None:
            result['AvgFrows'] = self.avg_frows

        if self.avg_iowrites is not None:
            result['AvgIOWrites'] = self.avg_iowrites

        if self.avg_keys_examined is not None:
            result['AvgKeysExamined'] = self.avg_keys_examined

        if self.avg_last_rows_count_affected is not None:
            result['AvgLastRowsCountAffected'] = self.avg_last_rows_count_affected

        if self.avg_lock_time is not None:
            result['AvgLockTime'] = self.avg_lock_time

        if self.avg_lock_time_seconds is not None:
            result['AvgLockTimeSeconds'] = self.avg_lock_time_seconds

        if self.avg_logical_ioreads is not None:
            result['AvgLogicalIOReads'] = self.avg_logical_ioreads

        if self.avg_physical_ioreads is not None:
            result['AvgPhysicalIOReads'] = self.avg_physical_ioreads

        if self.avg_query_time is not None:
            result['AvgQueryTime'] = self.avg_query_time

        if self.avg_query_time_seconds is not None:
            result['AvgQueryTimeSeconds'] = self.avg_query_time_seconds

        if self.avg_request_size is not None:
            result['AvgRequestSize'] = self.avg_request_size

        if self.avg_response_size is not None:
            result['AvgResponseSize'] = self.avg_response_size

        if self.avg_return_num is not None:
            result['AvgReturnNum'] = self.avg_return_num

        if self.avg_rows is not None:
            result['AvgRows'] = self.avg_rows

        if self.avg_rows_count_affected is not None:
            result['AvgRowsCountAffected'] = self.avg_rows_count_affected

        if self.avg_rows_examined is not None:
            result['AvgRowsExamined'] = self.avg_rows_examined

        if self.avg_rows_sent is not None:
            result['AvgRowsSent'] = self.avg_rows_sent

        if self.avg_rt is not None:
            result['AvgRt'] = self.avg_rt

        if self.avg_scnt is not None:
            result['AvgScnt'] = self.avg_scnt

        if self.cputime is not None:
            result['CPUTime'] = self.cputime

        if self.cputime_seconds is not None:
            result['CPUTimeSeconds'] = self.cputime_seconds

        if self.client_ip is not None:
            result['ClientIp'] = self.client_ip

        if self.cmd is not None:
            result['Cmd'] = self.cmd

        if self.command is not None:
            result['Command'] = self.command

        if self.count is not None:
            result['Count'] = self.count

        if self.count_rate is not None:
            result['CountRate'] = self.count_rate

        if self.dbname is not None:
            result['DBName'] = self.dbname

        if self.database is not None:
            result['Database'] = self.database

        if self.db_id is not None:
            result['DbId'] = self.db_id

        if self.db_instance_name is not None:
            result['DbInstanceName'] = self.db_instance_name

        if self.doc_examined is not None:
            result['DocExamined'] = self.doc_examined

        if self.docs_examined is not None:
            result['DocsExamined'] = self.docs_examined

        if self.frows is not None:
            result['Frows'] = self.frows

        if self.histogram is not None:
            result['Histogram'] = self.histogram.to_map()

        if self.host_address is not None:
            result['HostAddress'] = self.host_address

        if self.host_ins_id is not None:
            result['HostInsId'] = self.host_ins_id

        if self.iowrites is not None:
            result['IOWrites'] = self.iowrites

        if self.ins_name is not None:
            result['InsName'] = self.ins_name

        if self.ins_role is not None:
            result['InsRole'] = self.ins_role

        if self.keys_examined is not None:
            result['KeysExamined'] = self.keys_examined

        if self.last_rows_count_affected is not None:
            result['LastRowsCountAffected'] = self.last_rows_count_affected

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.lock_time_seconds is not None:
            result['LockTimeSeconds'] = self.lock_time_seconds

        if self.logical_ioreads is not None:
            result['LogicalIOReads'] = self.logical_ioreads

        if self.max_cputime is not None:
            result['MaxCPUTime'] = self.max_cputime

        if self.max_cputime_seconds is not None:
            result['MaxCPUTimeSeconds'] = self.max_cputime_seconds

        if self.max_doc_examined is not None:
            result['MaxDocExamined'] = self.max_doc_examined

        if self.max_frows is not None:
            result['MaxFrows'] = self.max_frows

        if self.max_iowrites is not None:
            result['MaxIOWrites'] = self.max_iowrites

        if self.max_keys_examined is not None:
            result['MaxKeysExamined'] = self.max_keys_examined

        if self.max_last_rows_count_affected is not None:
            result['MaxLastRowsCountAffected'] = self.max_last_rows_count_affected

        if self.max_lock_time is not None:
            result['MaxLockTime'] = self.max_lock_time

        if self.max_lock_time_seconds is not None:
            result['MaxLockTimeSeconds'] = self.max_lock_time_seconds

        if self.max_logical_ioreads is not None:
            result['MaxLogicalIOReads'] = self.max_logical_ioreads

        if self.max_physical_ioreads is not None:
            result['MaxPhysicalIOReads'] = self.max_physical_ioreads

        if self.max_query_time is not None:
            result['MaxQueryTime'] = self.max_query_time

        if self.max_query_time_seconds is not None:
            result['MaxQueryTimeSeconds'] = self.max_query_time_seconds

        if self.max_request_size is not None:
            result['MaxRequestSize'] = self.max_request_size

        if self.max_response_size is not None:
            result['MaxResponseSize'] = self.max_response_size

        if self.max_return_num is not None:
            result['MaxReturnNum'] = self.max_return_num

        if self.max_rows is not None:
            result['MaxRows'] = self.max_rows

        if self.max_rows_count_affected is not None:
            result['MaxRowsCountAffected'] = self.max_rows_count_affected

        if self.max_rows_examined is not None:
            result['MaxRowsExamined'] = self.max_rows_examined

        if self.max_rows_sent is not None:
            result['MaxRowsSent'] = self.max_rows_sent

        if self.max_rt is not None:
            result['MaxRt'] = self.max_rt

        if self.max_scnt is not None:
            result['MaxScnt'] = self.max_scnt

        if self.namespace is not None:
            result['Namespace'] = self.namespace

        if self.node_type is not None:
            result['NodeType'] = self.node_type

        if self.op_type is not None:
            result['OpType'] = self.op_type

        if self.origin_alias is not None:
            result['OriginAlias'] = self.origin_alias

        if self.physical_ioreads is not None:
            result['PhysicalIOReads'] = self.physical_ioreads

        if self.psql is not None:
            result['Psql'] = self.psql

        if self.query_id is not None:
            result['QueryId'] = self.query_id

        if self.query_start_time is not None:
            result['QueryStartTime'] = self.query_start_time

        if self.query_time is not None:
            result['QueryTime'] = self.query_time

        if self.query_time_rate is not None:
            result['QueryTimeRate'] = self.query_time_rate

        if self.query_time_seconds is not None:
            result['QueryTimeSeconds'] = self.query_time_seconds

        if self.return_item_numbers is not None:
            result['ReturnItemNumbers'] = self.return_item_numbers

        if self.return_num is not None:
            result['ReturnNum'] = self.return_num

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.rows_count_affected is not None:
            result['RowsCountAffected'] = self.rows_count_affected

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.rule_id is not None:
            result['RuleId'] = self.rule_id

        if self.sqltext is not None:
            result['SQLText'] = self.sqltext

        if self.scheme is not None:
            result['Scheme'] = self.scheme

        if self.scnt is not None:
            result['Scnt'] = self.scnt

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_tag is not None:
            result['SqlTag'] = self.sql_tag.to_map()

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.sub_instance_id is not None:
            result['SubInstanceId'] = self.sub_instance_id

        if self.table_name is not None:
            result['TableName'] = self.table_name

        if self.thread_id is not None:
            result['ThreadId'] = self.thread_id

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        result['Trend'] = []
        if self.trend is not None:
            for k1 in self.trend:
                result['Trend'].append(k1.to_map() if k1 else None)

        if self.user is not None:
            result['User'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountName') is not None:
            self.account_name = m.get('AccountName')

        if m.get('AvgCPUTime') is not None:
            self.avg_cputime = m.get('AvgCPUTime')

        if m.get('AvgCPUTimeSeconds') is not None:
            self.avg_cputime_seconds = m.get('AvgCPUTimeSeconds')

        if m.get('AvgDocExamined') is not None:
            self.avg_doc_examined = m.get('AvgDocExamined')

        if m.get('AvgFrows') is not None:
            self.avg_frows = m.get('AvgFrows')

        if m.get('AvgIOWrites') is not None:
            self.avg_iowrites = m.get('AvgIOWrites')

        if m.get('AvgKeysExamined') is not None:
            self.avg_keys_examined = m.get('AvgKeysExamined')

        if m.get('AvgLastRowsCountAffected') is not None:
            self.avg_last_rows_count_affected = m.get('AvgLastRowsCountAffected')

        if m.get('AvgLockTime') is not None:
            self.avg_lock_time = m.get('AvgLockTime')

        if m.get('AvgLockTimeSeconds') is not None:
            self.avg_lock_time_seconds = m.get('AvgLockTimeSeconds')

        if m.get('AvgLogicalIOReads') is not None:
            self.avg_logical_ioreads = m.get('AvgLogicalIOReads')

        if m.get('AvgPhysicalIOReads') is not None:
            self.avg_physical_ioreads = m.get('AvgPhysicalIOReads')

        if m.get('AvgQueryTime') is not None:
            self.avg_query_time = m.get('AvgQueryTime')

        if m.get('AvgQueryTimeSeconds') is not None:
            self.avg_query_time_seconds = m.get('AvgQueryTimeSeconds')

        if m.get('AvgRequestSize') is not None:
            self.avg_request_size = m.get('AvgRequestSize')

        if m.get('AvgResponseSize') is not None:
            self.avg_response_size = m.get('AvgResponseSize')

        if m.get('AvgReturnNum') is not None:
            self.avg_return_num = m.get('AvgReturnNum')

        if m.get('AvgRows') is not None:
            self.avg_rows = m.get('AvgRows')

        if m.get('AvgRowsCountAffected') is not None:
            self.avg_rows_count_affected = m.get('AvgRowsCountAffected')

        if m.get('AvgRowsExamined') is not None:
            self.avg_rows_examined = m.get('AvgRowsExamined')

        if m.get('AvgRowsSent') is not None:
            self.avg_rows_sent = m.get('AvgRowsSent')

        if m.get('AvgRt') is not None:
            self.avg_rt = m.get('AvgRt')

        if m.get('AvgScnt') is not None:
            self.avg_scnt = m.get('AvgScnt')

        if m.get('CPUTime') is not None:
            self.cputime = m.get('CPUTime')

        if m.get('CPUTimeSeconds') is not None:
            self.cputime_seconds = m.get('CPUTimeSeconds')

        if m.get('ClientIp') is not None:
            self.client_ip = m.get('ClientIp')

        if m.get('Cmd') is not None:
            self.cmd = m.get('Cmd')

        if m.get('Command') is not None:
            self.command = m.get('Command')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('CountRate') is not None:
            self.count_rate = m.get('CountRate')

        if m.get('DBName') is not None:
            self.dbname = m.get('DBName')

        if m.get('Database') is not None:
            self.database = m.get('Database')

        if m.get('DbId') is not None:
            self.db_id = m.get('DbId')

        if m.get('DbInstanceName') is not None:
            self.db_instance_name = m.get('DbInstanceName')

        if m.get('DocExamined') is not None:
            self.doc_examined = m.get('DocExamined')

        if m.get('DocsExamined') is not None:
            self.docs_examined = m.get('DocsExamined')

        if m.get('Frows') is not None:
            self.frows = m.get('Frows')

        if m.get('Histogram') is not None:
            temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram()
            self.histogram = temp_model.from_map(m.get('Histogram'))

        if m.get('HostAddress') is not None:
            self.host_address = m.get('HostAddress')

        if m.get('HostInsId') is not None:
            self.host_ins_id = m.get('HostInsId')

        if m.get('IOWrites') is not None:
            self.iowrites = m.get('IOWrites')

        if m.get('InsName') is not None:
            self.ins_name = m.get('InsName')

        if m.get('InsRole') is not None:
            self.ins_role = m.get('InsRole')

        if m.get('KeysExamined') is not None:
            self.keys_examined = m.get('KeysExamined')

        if m.get('LastRowsCountAffected') is not None:
            self.last_rows_count_affected = m.get('LastRowsCountAffected')

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('LockTimeSeconds') is not None:
            self.lock_time_seconds = m.get('LockTimeSeconds')

        if m.get('LogicalIOReads') is not None:
            self.logical_ioreads = m.get('LogicalIOReads')

        if m.get('MaxCPUTime') is not None:
            self.max_cputime = m.get('MaxCPUTime')

        if m.get('MaxCPUTimeSeconds') is not None:
            self.max_cputime_seconds = m.get('MaxCPUTimeSeconds')

        if m.get('MaxDocExamined') is not None:
            self.max_doc_examined = m.get('MaxDocExamined')

        if m.get('MaxFrows') is not None:
            self.max_frows = m.get('MaxFrows')

        if m.get('MaxIOWrites') is not None:
            self.max_iowrites = m.get('MaxIOWrites')

        if m.get('MaxKeysExamined') is not None:
            self.max_keys_examined = m.get('MaxKeysExamined')

        if m.get('MaxLastRowsCountAffected') is not None:
            self.max_last_rows_count_affected = m.get('MaxLastRowsCountAffected')

        if m.get('MaxLockTime') is not None:
            self.max_lock_time = m.get('MaxLockTime')

        if m.get('MaxLockTimeSeconds') is not None:
            self.max_lock_time_seconds = m.get('MaxLockTimeSeconds')

        if m.get('MaxLogicalIOReads') is not None:
            self.max_logical_ioreads = m.get('MaxLogicalIOReads')

        if m.get('MaxPhysicalIOReads') is not None:
            self.max_physical_ioreads = m.get('MaxPhysicalIOReads')

        if m.get('MaxQueryTime') is not None:
            self.max_query_time = m.get('MaxQueryTime')

        if m.get('MaxQueryTimeSeconds') is not None:
            self.max_query_time_seconds = m.get('MaxQueryTimeSeconds')

        if m.get('MaxRequestSize') is not None:
            self.max_request_size = m.get('MaxRequestSize')

        if m.get('MaxResponseSize') is not None:
            self.max_response_size = m.get('MaxResponseSize')

        if m.get('MaxReturnNum') is not None:
            self.max_return_num = m.get('MaxReturnNum')

        if m.get('MaxRows') is not None:
            self.max_rows = m.get('MaxRows')

        if m.get('MaxRowsCountAffected') is not None:
            self.max_rows_count_affected = m.get('MaxRowsCountAffected')

        if m.get('MaxRowsExamined') is not None:
            self.max_rows_examined = m.get('MaxRowsExamined')

        if m.get('MaxRowsSent') is not None:
            self.max_rows_sent = m.get('MaxRowsSent')

        if m.get('MaxRt') is not None:
            self.max_rt = m.get('MaxRt')

        if m.get('MaxScnt') is not None:
            self.max_scnt = m.get('MaxScnt')

        if m.get('Namespace') is not None:
            self.namespace = m.get('Namespace')

        if m.get('NodeType') is not None:
            self.node_type = m.get('NodeType')

        if m.get('OpType') is not None:
            self.op_type = m.get('OpType')

        if m.get('OriginAlias') is not None:
            self.origin_alias = m.get('OriginAlias')

        if m.get('PhysicalIOReads') is not None:
            self.physical_ioreads = m.get('PhysicalIOReads')

        if m.get('Psql') is not None:
            self.psql = m.get('Psql')

        if m.get('QueryId') is not None:
            self.query_id = m.get('QueryId')

        if m.get('QueryStartTime') is not None:
            self.query_start_time = m.get('QueryStartTime')

        if m.get('QueryTime') is not None:
            self.query_time = m.get('QueryTime')

        if m.get('QueryTimeRate') is not None:
            self.query_time_rate = m.get('QueryTimeRate')

        if m.get('QueryTimeSeconds') is not None:
            self.query_time_seconds = m.get('QueryTimeSeconds')

        if m.get('ReturnItemNumbers') is not None:
            self.return_item_numbers = m.get('ReturnItemNumbers')

        if m.get('ReturnNum') is not None:
            self.return_num = m.get('ReturnNum')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('RowsCountAffected') is not None:
            self.rows_count_affected = m.get('RowsCountAffected')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('RuleId') is not None:
            self.rule_id = m.get('RuleId')

        if m.get('SQLText') is not None:
            self.sqltext = m.get('SQLText')

        if m.get('Scheme') is not None:
            self.scheme = m.get('Scheme')

        if m.get('Scnt') is not None:
            self.scnt = m.get('Scnt')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlTag') is not None:
            temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag()
            self.sql_tag = temp_model.from_map(m.get('SqlTag'))

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('SubInstanceId') is not None:
            self.sub_instance_id = m.get('SubInstanceId')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        if m.get('ThreadId') is not None:
            self.thread_id = m.get('ThreadId')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        self.trend = []
        if m.get('Trend') is not None:
            for k1 in m.get('Trend'):
                temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsTrend()
                self.trend.append(temp_model.from_map(k1))

        if m.get('User') is not None:
            self.user = m.get('User')

        return self

class DescribeSlowLogStatisticResponseBodyDataDataLogsTrend(DaraModel):
    def __init__(
        self,
        timestamp: int = None,
        value: Any = None,
    ):
        self.timestamp = timestamp
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

class DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag(DaraModel):
    def __init__(
        self,
        comments: str = None,
        sql_id: str = None,
        tags: str = None,
    ):
        self.comments = comments
        # SQL ID。
        self.sql_id = sql_id
        self.tags = tags

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.comments is not None:
            result['Comments'] = self.comments

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.tags is not None:
            result['Tags'] = self.tags

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Comments') is not None:
            self.comments = m.get('Comments')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('Tags') is not None:
            self.tags = m.get('Tags')

        return self

class DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram(DaraModel):
    def __init__(
        self,
        avg_lock_time: List[float] = None,
        avg_rows_examined: List[float] = None,
        avg_rows_sent: List[float] = None,
        avg_rt: List[float] = None,
        count: List[int] = None,
        item: List[main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem] = None,
        lock_time: List[float] = None,
        max_lock_time: List[float] = None,
        max_rows_examined: List[int] = None,
        max_rows_sent: List[int] = None,
        max_rt: List[float] = None,
        rows_examined: List[int] = None,
        rows_sent: List[int] = None,
        rt: List[float] = None,
        total: int = None,
        ts: List[int] = None,
        ts_end: List[int] = None,
    ):
        self.avg_lock_time = avg_lock_time
        self.avg_rows_examined = avg_rows_examined
        self.avg_rows_sent = avg_rows_sent
        self.avg_rt = avg_rt
        self.count = count
        self.item = item
        self.lock_time = lock_time
        self.max_lock_time = max_lock_time
        self.max_rows_examined = max_rows_examined
        self.max_rows_sent = max_rows_sent
        self.max_rt = max_rt
        self.rows_examined = rows_examined
        self.rows_sent = rows_sent
        self.rt = rt
        self.total = total
        self.ts = ts
        self.ts_end = ts_end

    def validate(self):
        if self.item:
            for v1 in self.item:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_lock_time is not None:
            result['AvgLockTime'] = self.avg_lock_time

        if self.avg_rows_examined is not None:
            result['AvgRowsExamined'] = self.avg_rows_examined

        if self.avg_rows_sent is not None:
            result['AvgRowsSent'] = self.avg_rows_sent

        if self.avg_rt is not None:
            result['AvgRt'] = self.avg_rt

        if self.count is not None:
            result['Count'] = self.count

        result['Item'] = []
        if self.item is not None:
            for k1 in self.item:
                result['Item'].append(k1.to_map() if k1 else None)

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.max_lock_time is not None:
            result['MaxLockTime'] = self.max_lock_time

        if self.max_rows_examined is not None:
            result['MaxRowsExamined'] = self.max_rows_examined

        if self.max_rows_sent is not None:
            result['MaxRowsSent'] = self.max_rows_sent

        if self.max_rt is not None:
            result['MaxRt'] = self.max_rt

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.rt is not None:
            result['Rt'] = self.rt

        if self.total is not None:
            result['Total'] = self.total

        if self.ts is not None:
            result['Ts'] = self.ts

        if self.ts_end is not None:
            result['TsEnd'] = self.ts_end

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgLockTime') is not None:
            self.avg_lock_time = m.get('AvgLockTime')

        if m.get('AvgRowsExamined') is not None:
            self.avg_rows_examined = m.get('AvgRowsExamined')

        if m.get('AvgRowsSent') is not None:
            self.avg_rows_sent = m.get('AvgRowsSent')

        if m.get('AvgRt') is not None:
            self.avg_rt = m.get('AvgRt')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        self.item = []
        if m.get('Item') is not None:
            for k1 in m.get('Item'):
                temp_model = main_models.DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem()
                self.item.append(temp_model.from_map(k1))

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('MaxLockTime') is not None:
            self.max_lock_time = m.get('MaxLockTime')

        if m.get('MaxRowsExamined') is not None:
            self.max_rows_examined = m.get('MaxRowsExamined')

        if m.get('MaxRowsSent') is not None:
            self.max_rows_sent = m.get('MaxRowsSent')

        if m.get('MaxRt') is not None:
            self.max_rt = m.get('MaxRt')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('Rt') is not None:
            self.rt = m.get('Rt')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        if m.get('Ts') is not None:
            self.ts = m.get('Ts')

        if m.get('TsEnd') is not None:
            self.ts_end = m.get('TsEnd')

        return self

class DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem(DaraModel):
    def __init__(
        self,
        count: List[int] = None,
        node_id: str = None,
    ):
        self.count = count
        self.node_id = node_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['Count'] = self.count

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class CreateSqlLogTaskRequest(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        filters: List[main_models.CreateSqlLogTaskRequestFilters] = None,
        instance_id: str = None,
        name: str = None,
        node_id: str = None,
        role: str = None,
        start_time: int = None,
        type: str = None,
    ):
        # The end of the time range to query. Specify the time in the UNIX timestamp format. Unit: milliseconds.
        self.end_time = end_time
        # The filter conditions.
        self.filters = filters
        # The ID of the database instance.
        self.instance_id = instance_id
        # The name of the task.
        self.name = name
        # The node ID.
        # 
        # >  This parameter is available only for instances that run in a cluster architecture. You can specify this parameter to query the offline tasks of a specific node. By default, if this parameter is not specified, the information about the offline tasks of the primary node is returned.
        self.node_id = node_id
        # The role of the node of the PolarDB-X 2.0 database instance. Valid values:
        # 
        # *   **polarx_cn**: compute node
        # *   **polarx_dn**: data node
        self.role = role
        # The beginning of the time range to query. Specify the time in the UNIX timestamp format. Unit: milliseconds.
        self.start_time = start_time
        # The type of the task. Valid values:
        # 
        # *   **Export**
        # *   **Query**
        # *   **Insight**
        self.type = type

    def validate(self):
        if self.filters:
            for v1 in self.filters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        result['Filters'] = []
        if self.filters is not None:
            for k1 in self.filters:
                result['Filters'].append(k1.to_map() if k1 else None)

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.name is not None:
            result['Name'] = self.name

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.role is not None:
            result['Role'] = self.role

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        self.filters = []
        if m.get('Filters') is not None:
            for k1 in m.get('Filters'):
                temp_model = main_models.CreateSqlLogTaskRequestFilters()
                self.filters.append(temp_model.from_map(k1))

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Role') is not None:
            self.role = m.get('Role')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class CreateSqlLogTaskRequestFilters(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The name of the filter parameter.
        # 
        # >  For more information about the supported filter parameters and their valid values, see the following **supplement about the Key parameter**.
        self.key = key
        # The value of the filter parameter.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetMongoDBCurrentOpResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetMongoDBCurrentOpResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The response code.
        self.code = code
        # The details of the sessions.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetMongoDBCurrentOpResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetMongoDBCurrentOpResponseBodyData(DaraModel):
    def __init__(
        self,
        session_list: List[main_models.GetMongoDBCurrentOpResponseBodyDataSessionList] = None,
        session_stat: main_models.GetMongoDBCurrentOpResponseBodyDataSessionStat = None,
        timestamp: int = None,
    ):
        # The sessions.
        self.session_list = session_list
        # The statistics on the sessions.
        self.session_stat = session_stat
        # The time when the database sessions were returned. The value is in the UNIX timestamp format. Unit: milliseconds.
        self.timestamp = timestamp

    def validate(self):
        if self.session_list:
            for v1 in self.session_list:
                 if v1:
                    v1.validate()
        if self.session_stat:
            self.session_stat.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['SessionList'] = []
        if self.session_list is not None:
            for k1 in self.session_list:
                result['SessionList'].append(k1.to_map() if k1 else None)

        if self.session_stat is not None:
            result['SessionStat'] = self.session_stat.to_map()

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.session_list = []
        if m.get('SessionList') is not None:
            for k1 in m.get('SessionList'):
                temp_model = main_models.GetMongoDBCurrentOpResponseBodyDataSessionList()
                self.session_list.append(temp_model.from_map(k1))

        if m.get('SessionStat') is not None:
            temp_model = main_models.GetMongoDBCurrentOpResponseBodyDataSessionStat()
            self.session_stat = temp_model.from_map(m.get('SessionStat'))

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class GetMongoDBCurrentOpResponseBodyDataSessionStat(DaraModel):
    def __init__(
        self,
        active_count: int = None,
        client_stats: Dict[str, main_models.DataSessionStatClientStatsValue] = None,
        db_stats: Dict[str, main_models.DataSessionStatDbStatsValue] = None,
        longest_secs_running: int = None,
        total_count: int = None,
    ):
        # The number of active sessions.
        self.active_count = active_count
        # The statistics on the IP addresses of the clients.
        self.client_stats = client_stats
        # The statistics on the namespaces.
        self.db_stats = db_stats
        # The longest duration of a session. Unit: seconds.
        self.longest_secs_running = longest_secs_running
        # The total number of sessions.
        self.total_count = total_count

    def validate(self):
        if self.client_stats:
            for v1 in self.client_stats.values():
                 if v1:
                    v1.validate()
        if self.db_stats:
            for v1 in self.db_stats.values():
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_count is not None:
            result['ActiveCount'] = self.active_count

        result['ClientStats'] = {}
        if self.client_stats is not None:
            for k1, v1 in self.client_stats.items():
                result['ClientStats'][k1] = v1.to_map() if v1 else None

        result['DbStats'] = {}
        if self.db_stats is not None:
            for k1, v1 in self.db_stats.items():
                result['DbStats'][k1] = v1.to_map() if v1 else None

        if self.longest_secs_running is not None:
            result['LongestSecsRunning'] = self.longest_secs_running

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActiveCount') is not None:
            self.active_count = m.get('ActiveCount')

        self.client_stats = {}
        if m.get('ClientStats') is not None:
            for k1, v1 in m.get('ClientStats').items():
                temp_model = main_models.DataSessionStatClientStatsValue()
                self.client_stats[k1] = temp_model.from_map(v1)

        self.db_stats = {}
        if m.get('DbStats') is not None:
            for k1, v1 in m.get('DbStats').items():
                temp_model = main_models.DataSessionStatDbStatsValue()
                self.db_stats[k1] = temp_model.from_map(v1)

        if m.get('LongestSecsRunning') is not None:
            self.longest_secs_running = m.get('LongestSecsRunning')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class GetMongoDBCurrentOpResponseBodyDataSessionList(DaraModel):
    def __init__(
        self,
        active: bool = None,
        client: str = None,
        command: str = None,
        connection_id: int = None,
        desc: str = None,
        driver: str = None,
        host: str = None,
        kill_pending: bool = None,
        ns: str = None,
        op: str = None,
        op_id: str = None,
        os_arch: str = None,
        os_name: str = None,
        os_type: str = None,
        plan_summary: str = None,
        platform: str = None,
        secs_running: int = None,
        shard: str = None,
    ):
        # Indicates whether the operation is active. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.active = active
        # The IP address of the client.
        self.client = client
        # The document that contains the complete command object associated with the operation.
        self.command = command
        # The connection ID.
        self.connection_id = connection_id
        # The description of the connection.
        self.desc = desc
        # The driver for MongoDB.
        self.driver = driver
        # The host.
        self.host = host
        # Indicates whether the operation is marked as terminated.
        # 
        # *   **true**
        # *   **false**
        self.kill_pending = kill_pending
        # The namespace.
        self.ns = ns
        # The type of the operation.
        self.op = op
        # The operation ID.
        self.op_id = op_id
        # The architecture of the operating system.
        self.os_arch = os_arch
        # The name of the operating system.
        self.os_name = os_name
        # The type of the operating system.
        self.os_type = os_type
        # The description of the execution plan.
        self.plan_summary = plan_summary
        # The platform.
        self.platform = platform
        # The duration of the operation. Unit: seconds.
        self.secs_running = secs_running
        # The ID of the data shard.
        # 
        # >  This parameter is returned for sharded cluster instances.
        self.shard = shard

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active is not None:
            result['Active'] = self.active

        if self.client is not None:
            result['Client'] = self.client

        if self.command is not None:
            result['Command'] = self.command

        if self.connection_id is not None:
            result['ConnectionId'] = self.connection_id

        if self.desc is not None:
            result['Desc'] = self.desc

        if self.driver is not None:
            result['Driver'] = self.driver

        if self.host is not None:
            result['Host'] = self.host

        if self.kill_pending is not None:
            result['KillPending'] = self.kill_pending

        if self.ns is not None:
            result['Ns'] = self.ns

        if self.op is not None:
            result['Op'] = self.op

        if self.op_id is not None:
            result['OpId'] = self.op_id

        if self.os_arch is not None:
            result['OsArch'] = self.os_arch

        if self.os_name is not None:
            result['OsName'] = self.os_name

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.plan_summary is not None:
            result['PlanSummary'] = self.plan_summary

        if self.platform is not None:
            result['Platform'] = self.platform

        if self.secs_running is not None:
            result['SecsRunning'] = self.secs_running

        if self.shard is not None:
            result['Shard'] = self.shard

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Active') is not None:
            self.active = m.get('Active')

        if m.get('Client') is not None:
            self.client = m.get('Client')

        if m.get('Command') is not None:
            self.command = m.get('Command')

        if m.get('ConnectionId') is not None:
            self.connection_id = m.get('ConnectionId')

        if m.get('Desc') is not None:
            self.desc = m.get('Desc')

        if m.get('Driver') is not None:
            self.driver = m.get('Driver')

        if m.get('Host') is not None:
            self.host = m.get('Host')

        if m.get('KillPending') is not None:
            self.kill_pending = m.get('KillPending')

        if m.get('Ns') is not None:
            self.ns = m.get('Ns')

        if m.get('Op') is not None:
            self.op = m.get('Op')

        if m.get('OpId') is not None:
            self.op_id = m.get('OpId')

        if m.get('OsArch') is not None:
            self.os_arch = m.get('OsArch')

        if m.get('OsName') is not None:
            self.os_name = m.get('OsName')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('PlanSummary') is not None:
            self.plan_summary = m.get('PlanSummary')

        if m.get('Platform') is not None:
            self.platform = m.get('Platform')

        if m.get('SecsRunning') is not None:
            self.secs_running = m.get('SecsRunning')

        if m.get('Shard') is not None:
            self.shard = m.get('Shard')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetErrorRequestSampleResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: List[main_models.GetErrorRequestSampleResponseBodyData] = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.GetErrorRequestSampleResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetErrorRequestSampleResponseBodyData(DaraModel):
    def __init__(
        self,
        database: str = None,
        error_code: str = None,
        instance_id: str = None,
        origin_host: str = None,
        sql: str = None,
        sql_id: str = None,
        tables: List[str] = None,
        timestamp: int = None,
        user: str = None,
    ):
        # The database name.
        self.database = database
        # The error code that is returned.
        self.error_code = error_code
        # The instance ID.
        self.instance_id = instance_id
        # The IP address of the client that executes the SQL statement.
        self.origin_host = origin_host
        # The SQL statement.
        self.sql = sql
        # The SQL query ID.
        self.sql_id = sql_id
        # The table information.
        self.tables = tables
        # The time when the SQL query was executed. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The username of the account that is used to log on to the database.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.database is not None:
            result['database'] = self.database

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.origin_host is not None:
            result['originHost'] = self.origin_host

        if self.sql is not None:
            result['sql'] = self.sql

        if self.sql_id is not None:
            result['sqlId'] = self.sql_id

        if self.tables is not None:
            result['tables'] = self.tables

        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        if self.user is not None:
            result['user'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('database') is not None:
            self.database = m.get('database')

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('originHost') is not None:
            self.origin_host = m.get('originHost')

        if m.get('sql') is not None:
            self.sql = m.get('sql')

        if m.get('sqlId') is not None:
            self.sql_id = m.get('sqlId')

        if m.get('tables') is not None:
            self.tables = m.get('tables')

        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        if m.get('user') is not None:
            self.user = m.get('user')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DisableAutoThrottleRulesRequest(DaraModel):
    def __init__(
        self,
        console_context: str = None,
        instance_ids: str = None,
    ):
        # The reserved parameter.
        self.console_context = console_context
        # The database instance IDs.
        # 
        # >  Set this parameter to a JSON array that consists of multiple instance IDs. Separate instance IDs with commas (,). Example: `[\\"Instance ID1\\",\\"Instance ID2\\"]`.
        # 
        # This parameter is required.
        self.instance_ids = instance_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetDasProServiceUsageResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetDasProServiceUsageResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetDasProServiceUsageResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetDasProServiceUsageResponseBodyData(DaraModel):
    def __init__(
        self,
        commodity_instance_id: str = None,
        engine: str = None,
        expire_time: int = None,
        instance_alias: str = None,
        instance_id: str = None,
        ip: str = None,
        is_spare: bool = None,
        migration_predict_remaining_time: int = None,
        port: int = None,
        region: str = None,
        service_unit_id: str = None,
        sql_retention: str = None,
        start_time: int = None,
        storage_free_quota_in_mb: float = None,
        storage_used: int = None,
        user_id: str = None,
        vpc_id: str = None,
    ):
        # The ID of the DAS Enterprise Edition instance.
        self.commodity_instance_id = commodity_instance_id
        # The type of the database engine.
        self.engine = engine
        # The point of time when DAS Enterprise Edition for the database instance expires. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.expire_time = expire_time
        # The name of the database instance.
        self.instance_alias = instance_alias
        # The database instance ID.
        self.instance_id = instance_id
        # The endpoint of the database instance.
        self.ip = ip
        # Indicates whether DAS Enterprise Edition for the database instance has expired. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_spare = is_spare
        # The estimated remaining time for migrating the data generated by the SQL Explorer and Audit feature from the previous version to the new version. Unit: milliseconds.
        # 
        # >  This parameter is returned only when the SQL Explorer and Audit feature is migrated from the previous version to the new version.
        self.migration_predict_remaining_time = migration_predict_remaining_time
        # The port number that is used to connect to the database instance.
        self.port = port
        # The region in which the database instance resides.
        self.region = region
        # The service unit ID.
        self.service_unit_id = service_unit_id
        # The storage duration of SQL Explorer data. Unit: days.
        self.sql_retention = sql_retention
        # The time when DAS Enterprise Edition was enabled for the database instance. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start_time = start_time
        # The SQL Explorer storage space that is offered free-of-charge. Unit: MB.
        self.storage_free_quota_in_mb = storage_free_quota_in_mb
        # The storage usage of SQL Explorer of the database instance. Unit: bytes.
        self.storage_used = storage_used
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id
        # The virtual private cloud (VPC) ID.
        self.vpc_id = vpc_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.commodity_instance_id is not None:
            result['commodityInstanceId'] = self.commodity_instance_id

        if self.engine is not None:
            result['engine'] = self.engine

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.instance_alias is not None:
            result['instanceAlias'] = self.instance_alias

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.ip is not None:
            result['ip'] = self.ip

        if self.is_spare is not None:
            result['isSpare'] = self.is_spare

        if self.migration_predict_remaining_time is not None:
            result['migrationPredictRemainingTime'] = self.migration_predict_remaining_time

        if self.port is not None:
            result['port'] = self.port

        if self.region is not None:
            result['region'] = self.region

        if self.service_unit_id is not None:
            result['serviceUnitId'] = self.service_unit_id

        if self.sql_retention is not None:
            result['sqlRetention'] = self.sql_retention

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.storage_free_quota_in_mb is not None:
            result['storageFreeQuotaInMB'] = self.storage_free_quota_in_mb

        if self.storage_used is not None:
            result['storageUsed'] = self.storage_used

        if self.user_id is not None:
            result['userId'] = self.user_id

        if self.vpc_id is not None:
            result['vpcId'] = self.vpc_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('commodityInstanceId') is not None:
            self.commodity_instance_id = m.get('commodityInstanceId')

        if m.get('engine') is not None:
            self.engine = m.get('engine')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('instanceAlias') is not None:
            self.instance_alias = m.get('instanceAlias')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('ip') is not None:
            self.ip = m.get('ip')

        if m.get('isSpare') is not None:
            self.is_spare = m.get('isSpare')

        if m.get('migrationPredictRemainingTime') is not None:
            self.migration_predict_remaining_time = m.get('migrationPredictRemainingTime')

        if m.get('port') is not None:
            self.port = m.get('port')

        if m.get('region') is not None:
            self.region = m.get('region')

        if m.get('serviceUnitId') is not None:
            self.service_unit_id = m.get('serviceUnitId')

        if m.get('sqlRetention') is not None:
            self.sql_retention = m.get('sqlRetention')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('storageFreeQuotaInMB') is not None:
            self.storage_free_quota_in_mb = m.get('storageFreeQuotaInMB')

        if m.get('storageUsed') is not None:
            self.storage_used = m.get('storageUsed')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        if m.get('vpcId') is not None:
            self.vpc_id = m.get('vpcId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetQueryOptimizeDataStatsResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetQueryOptimizeDataStatsResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetQueryOptimizeDataStatsResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetQueryOptimizeDataStatsResponseBodyData(DaraModel):
    def __init__(
        self,
        extra: str = None,
        list: List[main_models.GetQueryOptimizeDataStatsResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The reserved parameter.
        self.extra = extra
        # The information about the SQL templates.
        self.list = list
        # The reserved parameter.
        self.page_no = page_no
        # The reserved parameter.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extra is not None:
            result['Extra'] = self.extra

        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Extra') is not None:
            self.extra = m.get('Extra')

        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetQueryOptimizeDataStatsResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetQueryOptimizeDataStatsResponseBodyDataList(DaraModel):
    def __init__(
        self,
        avg_lock_time: float = None,
        avg_query_time: float = None,
        avg_rows_affected: float = None,
        avg_rows_examined: float = None,
        avg_rows_sent: float = None,
        count: int = None,
        dbname: str = None,
        instance_id: str = None,
        max_lock_time: float = None,
        max_query_time: float = None,
        max_rows_affected: int = None,
        max_rows_examined: int = None,
        max_rows_sent: int = None,
        psql: str = None,
        rule_list: List[main_models.GetQueryOptimizeDataStatsResponseBodyDataListRuleList] = None,
        sql_id: str = None,
        sql_sample: str = None,
        sql_type: str = None,
        user: str = None,
    ):
        # The average lock wait time. Unit: seconds.
        self.avg_lock_time = avg_lock_time
        # The average query execution time. Unit: seconds.
        self.avg_query_time = avg_query_time
        # The average number of rows affected by the SQL statement.
        # 
        # > A value of -1 indicates that this parameter is not collected.
        self.avg_rows_affected = avg_rows_affected
        # The average number of scanned rows.
        self.avg_rows_examined = avg_rows_examined
        # The average number of returned rows.
        self.avg_rows_sent = avg_rows_sent
        # The number of times that the SQL template is executed.
        self.count = count
        # The name of the database to which the SQL template belongs.
        self.dbname = dbname
        # The instance ID.
        self.instance_id = instance_id
        # The longest lock wait time. Unit: seconds.
        self.max_lock_time = max_lock_time
        # The longest query execution time. Unit: seconds.
        self.max_query_time = max_query_time
        # The largest number of rows affected by the SQL template.
        # 
        # > A value of -1 indicates that this parameter is not collected.
        self.max_rows_affected = max_rows_affected
        # The largest number of scanned rows.
        self.max_rows_examined = max_rows_examined
        # The largest number of returned rows.
        self.max_rows_sent = max_rows_sent
        # The SQL template.
        self.psql = psql
        # The information about the rules.
        self.rule_list = rule_list
        # The SQL template ID.
        self.sql_id = sql_id
        # The sample query that took the longest time to execute.
        self.sql_sample = sql_sample
        # The type of the SQL statement.
        self.sql_type = sql_type
        # The account of the database.
        self.user = user

    def validate(self):
        if self.rule_list:
            for v1 in self.rule_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_lock_time is not None:
            result['AvgLockTime'] = self.avg_lock_time

        if self.avg_query_time is not None:
            result['AvgQueryTime'] = self.avg_query_time

        if self.avg_rows_affected is not None:
            result['AvgRowsAffected'] = self.avg_rows_affected

        if self.avg_rows_examined is not None:
            result['AvgRowsExamined'] = self.avg_rows_examined

        if self.avg_rows_sent is not None:
            result['AvgRowsSent'] = self.avg_rows_sent

        if self.count is not None:
            result['Count'] = self.count

        if self.dbname is not None:
            result['Dbname'] = self.dbname

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.max_lock_time is not None:
            result['MaxLockTime'] = self.max_lock_time

        if self.max_query_time is not None:
            result['MaxQueryTime'] = self.max_query_time

        if self.max_rows_affected is not None:
            result['MaxRowsAffected'] = self.max_rows_affected

        if self.max_rows_examined is not None:
            result['MaxRowsExamined'] = self.max_rows_examined

        if self.max_rows_sent is not None:
            result['MaxRowsSent'] = self.max_rows_sent

        if self.psql is not None:
            result['Psql'] = self.psql

        result['RuleList'] = []
        if self.rule_list is not None:
            for k1 in self.rule_list:
                result['RuleList'].append(k1.to_map() if k1 else None)

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_sample is not None:
            result['SqlSample'] = self.sql_sample

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.user is not None:
            result['User'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgLockTime') is not None:
            self.avg_lock_time = m.get('AvgLockTime')

        if m.get('AvgQueryTime') is not None:
            self.avg_query_time = m.get('AvgQueryTime')

        if m.get('AvgRowsAffected') is not None:
            self.avg_rows_affected = m.get('AvgRowsAffected')

        if m.get('AvgRowsExamined') is not None:
            self.avg_rows_examined = m.get('AvgRowsExamined')

        if m.get('AvgRowsSent') is not None:
            self.avg_rows_sent = m.get('AvgRowsSent')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Dbname') is not None:
            self.dbname = m.get('Dbname')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('MaxLockTime') is not None:
            self.max_lock_time = m.get('MaxLockTime')

        if m.get('MaxQueryTime') is not None:
            self.max_query_time = m.get('MaxQueryTime')

        if m.get('MaxRowsAffected') is not None:
            self.max_rows_affected = m.get('MaxRowsAffected')

        if m.get('MaxRowsExamined') is not None:
            self.max_rows_examined = m.get('MaxRowsExamined')

        if m.get('MaxRowsSent') is not None:
            self.max_rows_sent = m.get('MaxRowsSent')

        if m.get('Psql') is not None:
            self.psql = m.get('Psql')

        self.rule_list = []
        if m.get('RuleList') is not None:
            for k1 in m.get('RuleList'):
                temp_model = main_models.GetQueryOptimizeDataStatsResponseBodyDataListRuleList()
                self.rule_list.append(temp_model.from_map(k1))

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlSample') is not None:
            self.sql_sample = m.get('SqlSample')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('User') is not None:
            self.user = m.get('User')

        return self

class GetQueryOptimizeDataStatsResponseBodyDataListRuleList(DaraModel):
    def __init__(
        self,
        name: str = None,
        type: str = None,
    ):
        # The rule name.
        self.name = name
        # The type of the rule. Valid values:
        # 
        # * **Predefined**
        # * **UserDefined**
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['Name'] = self.name

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeCloudBenchTasksRequest(DaraModel):
    def __init__(
        self,
        end_time: str = None,
        page_no: str = None,
        page_size: str = None,
        start_time: str = None,
        status: str = None,
        task_type: str = None,
    ):
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time.
        self.end_time = end_time
        # The page number. The value must be a positive integer. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. The value must be a positive integer. Default value: 10.
        self.page_size = page_size
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start_time = start_time
        # The status of the stress testing task. Valid values:
        # 
        # *   **SUCCESS**: The task is successful.
        # *   **IGNORED**: The task is ignored.
        # *   **RUNNING**: The task is running.
        # *   **EXCEPTION**: The task is abnormal.
        self.status = status
        # The type of the stress testing task. Valid values:
        # 
        # *   **pressure test** (default): A task of this type replays the traffic that is captured from the source instance on the destination instance at the maximum playback rate that is supported by the destination instance.
        # *   **smart pressure test**: A task of this type analyzes the traffic that is captured from the source instance over a short period of time and generates traffic on the destination instance for continuous stress testing. The business model based on which the traffic is generated on the destination instance and the traffic distribution are consistent with those on the source instance. Stress testing tasks of this type can help you reduce the amount of time that is consumed to collect data from the source instance and reduce storage costs and performance overheads.
        self.task_type = task_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.status is not None:
            result['Status'] = self.status

        if self.task_type is not None:
            result['TaskType'] = self.task_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskType') is not None:
            self.task_type = m.get('TaskType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict, Any

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeAutoScalingHistoryResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeAutoScalingHistoryResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned. The status code 200 indicates that the request was successful.
        self.code = code
        # The history of auto scaling.
        self.data = data
        # The returned message.
        # 
        # > If the request was successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeAutoScalingHistoryResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeAutoScalingHistoryResponseBodyData(DaraModel):
    def __init__(
        self,
        bandwidth: List[Dict[str, Any]] = None,
        instance_id: str = None,
        resource: List[Dict[str, Any]] = None,
        shard: List[Dict[str, Any]] = None,
        spec_history: List[main_models.DescribeAutoScalingHistoryResponseBodyDataSpecHistory] = None,
        storage: List[Dict[str, Any]] = None,
    ):
        # The history of automatic bandwidth scaling of ApsaraDB for Redis instances. This feature is not supported.
        self.bandwidth = bandwidth
        # The instance ID.
        self.instance_id = instance_id
        # The history of resource scale-out of ApsaraDB for Redis instances. This feature is not supported.
        self.resource = resource
        # The history of automatic shard scale-out of ApsaraDB for Redis instances. This feature is not supported.
        self.shard = shard
        # The history of automatic performance scaling.
        self.spec_history = spec_history
        # The history of storage expansion. This feature is not supported.
        self.storage = storage

    def validate(self):
        if self.spec_history:
            for v1 in self.spec_history:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.resource is not None:
            result['Resource'] = self.resource

        if self.shard is not None:
            result['Shard'] = self.shard

        result['SpecHistory'] = []
        if self.spec_history is not None:
            for k1 in self.spec_history:
                result['SpecHistory'].append(k1.to_map() if k1 else None)

        if self.storage is not None:
            result['Storage'] = self.storage

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bandwidth') is not None:
            self.bandwidth = m.get('Bandwidth')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Resource') is not None:
            self.resource = m.get('Resource')

        if m.get('Shard') is not None:
            self.shard = m.get('Shard')

        self.spec_history = []
        if m.get('SpecHistory') is not None:
            for k1 in m.get('SpecHistory'):
                temp_model = main_models.DescribeAutoScalingHistoryResponseBodyDataSpecHistory()
                self.spec_history.append(temp_model.from_map(k1))

        if m.get('Storage') is not None:
            self.storage = m.get('Storage')

        return self

class DescribeAutoScalingHistoryResponseBodyDataSpecHistory(DaraModel):
    def __init__(
        self,
        error_code: str = None,
        origin_core: int = None,
        origin_instance_class: str = None,
        origin_memory: float = None,
        scale_type: str = None,
        target_core: int = None,
        target_instance_class: str = None,
        target_memory: float = None,
        task_excute_status: bool = None,
        task_time: int = None,
    ):
        # The error code returned by the scaling task. Valid values:
        # 
        # *   **Insufficient_Balance**: The account has insufficient balance or an unpaid order.
        # *   **REACH_SPEC_UPPERBOUND**: The instance type reaches the upper limit.
        # *   **Control_Error_Timeout_Msg**: The management task timed out.
        # *   **Invoke_Rds_Api_Error_Msg**: Failed to call the ApsaraDB RDS API.
        self.error_code = error_code
        # The original number of CPU cores of the instance.
        self.origin_core = origin_core
        # The original instance type.
        self.origin_instance_class = origin_instance_class
        # The original memory size of the instance. Unit: GB.
        self.origin_memory = origin_memory
        # The type of the automatic performance scaling task. Valid values:
        # 
        # *   **SCALE_UP**: automatic instance type scale-up task.
        # *   **SCALE_DOWN**: automatic instance type scale-down task.
        self.scale_type = scale_type
        # The destination number of CPU cores of the instance.
        self.target_core = target_core
        # The destination instance type.
        self.target_instance_class = target_instance_class
        # The destination memory size of the instance. Unit: GB.
        self.target_memory = target_memory
        # The status of the task. Valid values:
        # 
        # *   **true**: The task was successful.
        # *   **false**: The task failed.
        self.task_excute_status = task_excute_status
        # The time when the task was run. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.task_time = task_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.origin_core is not None:
            result['OriginCore'] = self.origin_core

        if self.origin_instance_class is not None:
            result['OriginInstanceClass'] = self.origin_instance_class

        if self.origin_memory is not None:
            result['OriginMemory'] = self.origin_memory

        if self.scale_type is not None:
            result['ScaleType'] = self.scale_type

        if self.target_core is not None:
            result['TargetCore'] = self.target_core

        if self.target_instance_class is not None:
            result['TargetInstanceClass'] = self.target_instance_class

        if self.target_memory is not None:
            result['TargetMemory'] = self.target_memory

        if self.task_excute_status is not None:
            result['TaskExcuteStatus'] = self.task_excute_status

        if self.task_time is not None:
            result['TaskTime'] = self.task_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('OriginCore') is not None:
            self.origin_core = m.get('OriginCore')

        if m.get('OriginInstanceClass') is not None:
            self.origin_instance_class = m.get('OriginInstanceClass')

        if m.get('OriginMemory') is not None:
            self.origin_memory = m.get('OriginMemory')

        if m.get('ScaleType') is not None:
            self.scale_type = m.get('ScaleType')

        if m.get('TargetCore') is not None:
            self.target_core = m.get('TargetCore')

        if m.get('TargetInstanceClass') is not None:
            self.target_instance_class = m.get('TargetInstanceClass')

        if m.get('TargetMemory') is not None:
            self.target_memory = m.get('TargetMemory')

        if m.get('TaskExcuteStatus') is not None:
            self.task_excute_status = m.get('TaskExcuteStatus')

        if m.get('TaskTime') is not None:
            self.task_time = m.get('TaskTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetStorageAnalysisResultRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        node_id: str = None,
        task_id: str = None,
    ):
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  This parameter is reserved.
        self.node_id = node_id
        # The task ID. You can obtain the task ID from the response of the [CreateStorageAnalysisTask](https://help.aliyun.com/document_detail/2639140.html) operation.
        # 
        # This parameter is required.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetQueryOptimizeDataStatsRequest(DaraModel):
    def __init__(
        self,
        asc: str = None,
        db_names: str = None,
        engine: str = None,
        instance_ids: str = None,
        keywords: str = None,
        logical_operator: str = None,
        only_optimized_sql: str = None,
        order_by: str = None,
        page_no: str = None,
        page_size: str = None,
        region: str = None,
        rules: str = None,
        sql_ids: str = None,
        tag_names: str = None,
        time: str = None,
        user: str = None,
    ):
        # Specifies whether to sort the returned entries in ascending order. Default value: **true**. Valid values:
        # 
        # *   **true**: sorts the returned entries in ascending order.
        # *   **false**: does not sort the returned entries in ascending order.
        self.asc = asc
        # The name of the database to be queried.
        self.db_names = db_names
        # The database engine. Valid values:
        # 
        # *   **MySQL**
        # *   **PolarDBMySQL**
        # *   **PostgreSQL**
        # 
        # This parameter is required.
        self.engine = engine
        # The instance IDs. Separate multiple IDs with commas (,).
        self.instance_ids = instance_ids
        # The keywords of the SQL template. Separate multiple keywords with spaces.
        self.keywords = keywords
        # The logical relationship between multiple keywords. Valid values:
        # 
        # *   **or**
        # *   **and**
        self.logical_operator = logical_operator
        # Specifies whether to query only SQL templates that need to be optimized. Default value: **false**. Valid values:
        # 
        # *   **true**: queries only SQL templates that need to be optimized.
        # *   **false**: does not query only SQL statements that need to be optimized.
        self.only_optimized_sql = only_optimized_sql
        # The field by which to sort the returned entries. Default value: **count**. Valid values:
        # 
        # *   **count**: the number of executions.
        # *   **maxQueryTime**: the longest execution time.
        # *   **avgQueryTime**: the average execution time.
        # *   **maxLockTime**: the longest lock wait time.
        # *   **avgLockTime**: the longest lock wait time.
        # *   **maxRowsExamined**: the largest number of scanned rows.
        # *   **avgRowsExamined**: the average number of scanned rows.
        # *   **maxRowsSent**: the largest number of returned rows.
        # *   **avgRowsSent**: the average number of returned rows.
        self.order_by = order_by
        # The page number. Pages start from page 1. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. Default value: 10.
        self.page_size = page_size
        # The region in which the instance resides. Valid values:
        # 
        # *   **cn-china**: Chinese mainland
        # *   **cn-hongkong**: China (Hong Kong)
        # *   **ap-southeast-1**: Singapore
        # 
        # This parameter takes effect only if **InstanceIds** is left empty. If you leave **InstanceIds** empty, the system obtains data from the region set by **Region**. By default, Region is set to **cn-china**. If you specify **InstanceIds**, **Region** does not take effect and the system obtains data from the region in which the first specified instance resides.****
        # 
        # >  Set this parameter to **cn-china** for the instances that are created in the regions in the Chinese mainland.
        self.region = region
        # The tags that are used to filter SQL templates. Separate multiple tags with commas (,). For more information, see [Query governance](https://help.aliyun.com/document_detail/290038.html).
        self.rules = rules
        # The SQL template ID. You can query the ID of a template by calling the [GetQueryOptimizeExecErrorStats](https://help.aliyun.com/document_detail/405235.html) operation.
        self.sql_ids = sql_ids
        # The reserved parameter.
        self.tag_names = tag_names
        # The time range to query. Specify the time in the UNIX timestamp format. Unit: milliseconds.
        # 
        # This parameter is required.
        self.time = time
        # The account of the database to be queried.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.asc is not None:
            result['Asc'] = self.asc

        if self.db_names is not None:
            result['DbNames'] = self.db_names

        if self.engine is not None:
            result['Engine'] = self.engine

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        if self.keywords is not None:
            result['Keywords'] = self.keywords

        if self.logical_operator is not None:
            result['LogicalOperator'] = self.logical_operator

        if self.only_optimized_sql is not None:
            result['OnlyOptimizedSql'] = self.only_optimized_sql

        if self.order_by is not None:
            result['OrderBy'] = self.order_by

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.region is not None:
            result['Region'] = self.region

        if self.rules is not None:
            result['Rules'] = self.rules

        if self.sql_ids is not None:
            result['SqlIds'] = self.sql_ids

        if self.tag_names is not None:
            result['TagNames'] = self.tag_names

        if self.time is not None:
            result['Time'] = self.time

        if self.user is not None:
            result['User'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Asc') is not None:
            self.asc = m.get('Asc')

        if m.get('DbNames') is not None:
            self.db_names = m.get('DbNames')

        if m.get('Engine') is not None:
            self.engine = m.get('Engine')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        if m.get('Keywords') is not None:
            self.keywords = m.get('Keywords')

        if m.get('LogicalOperator') is not None:
            self.logical_operator = m.get('LogicalOperator')

        if m.get('OnlyOptimizedSql') is not None:
            self.only_optimized_sql = m.get('OnlyOptimizedSql')

        if m.get('OrderBy') is not None:
            self.order_by = m.get('OrderBy')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Region') is not None:
            self.region = m.get('Region')

        if m.get('Rules') is not None:
            self.rules = m.get('Rules')

        if m.get('SqlIds') is not None:
            self.sql_ids = m.get('SqlIds')

        if m.get('TagNames') is not None:
            self.tag_names = m.get('TagNames')

        if m.get('Time') is not None:
            self.time = m.get('Time')

        if m.get('User') is not None:
            self.user = m.get('User')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetFullRequestSampleByInstanceIdResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: List[main_models.GetFullRequestSampleByInstanceIdResponseBodyData] = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message that contains information such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.GetFullRequestSampleByInstanceIdResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetFullRequestSampleByInstanceIdResponseBodyData(DaraModel):
    def __init__(
        self,
        database: str = None,
        frows: int = None,
        lock_wait_time: float = None,
        logical_read: float = None,
        origin_host: str = None,
        physical_async_read: float = None,
        physical_sync_read: float = None,
        rows: int = None,
        rows_examined: int = None,
        rows_returned: int = None,
        rt: float = None,
        scan_rows: int = None,
        scnt: int = None,
        sql: str = None,
        sql_id: str = None,
        sql_type: str = None,
        timestamp: int = None,
        update_rows: int = None,
        user: str = None,
    ):
        # The name of the database.
        self.database = database
        # The number of rows fetched by PolarDB-X 2.0 compute nodes.
        self.frows = frows
        # The lock wait duration. Unit: seconds.
        self.lock_wait_time = lock_wait_time
        # The number of logical reads.
        self.logical_read = logical_read
        # The source IP address.
        self.origin_host = origin_host
        # The number of physical asynchronous reads.
        self.physical_async_read = physical_async_read
        # The number of physical synchronous reads.
        self.physical_sync_read = physical_sync_read
        # The number of rows updated or returned on PolarDB-X 2.0 compute nodes.
        self.rows = rows
        # The total number of scanned rows.
        # 
        # > This parameter is returned only for ApsaraDB RDS for MySQL, ApsaraDB RDS for PostgreSQL, and PolarDB for MySQL databases.
        self.rows_examined = rows_examined
        # The number of rows returned by the SQL statement.
        self.rows_returned = rows_returned
        # The amount of time consumed to execute the SQL statement. Unit: seconds.
        self.rt = rt
        # The number of scanned rows.
        self.scan_rows = scan_rows
        # The number of requests sent from PolarDB-X 2.0 compute nodes to data nodes.
        self.scnt = scnt
        # The sample SQL statement.
        self.sql = sql
        # The SQL statement ID.
        self.sql_id = sql_id
        # The type of the SQL statement. Valid values: **SELECT**, **INSERT**, **UPDATE**, **DELETE**, **LOGIN**, **LOGOUT**, **MERGE**, **ALTER**, **CREATEINDEX**, **DROPINDEX**, **CREATE**, **DROP**, **SET**, **DESC**, **REPLACE**, **CALL**, **BEGIN**, **DESCRIBE**, **ROLLBACK**, **FLUSH**, **USE**, **SHOW**, **START**, **COMMIT**, and **RENAME**.
        self.sql_type = sql_type
        # The time when the SQL statement was executed. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The number of updated rows.
        self.update_rows = update_rows
        # The name of the user who executes the SQL statement.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.database is not None:
            result['Database'] = self.database

        if self.frows is not None:
            result['Frows'] = self.frows

        if self.lock_wait_time is not None:
            result['LockWaitTime'] = self.lock_wait_time

        if self.logical_read is not None:
            result['LogicalRead'] = self.logical_read

        if self.origin_host is not None:
            result['OriginHost'] = self.origin_host

        if self.physical_async_read is not None:
            result['PhysicalAsyncRead'] = self.physical_async_read

        if self.physical_sync_read is not None:
            result['PhysicalSyncRead'] = self.physical_sync_read

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_returned is not None:
            result['RowsReturned'] = self.rows_returned

        if self.rt is not None:
            result['Rt'] = self.rt

        if self.scan_rows is not None:
            result['ScanRows'] = self.scan_rows

        if self.scnt is not None:
            result['Scnt'] = self.scnt

        if self.sql is not None:
            result['Sql'] = self.sql

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.update_rows is not None:
            result['UpdateRows'] = self.update_rows

        if self.user is not None:
            result['User'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Database') is not None:
            self.database = m.get('Database')

        if m.get('Frows') is not None:
            self.frows = m.get('Frows')

        if m.get('LockWaitTime') is not None:
            self.lock_wait_time = m.get('LockWaitTime')

        if m.get('LogicalRead') is not None:
            self.logical_read = m.get('LogicalRead')

        if m.get('OriginHost') is not None:
            self.origin_host = m.get('OriginHost')

        if m.get('PhysicalAsyncRead') is not None:
            self.physical_async_read = m.get('PhysicalAsyncRead')

        if m.get('PhysicalSyncRead') is not None:
            self.physical_sync_read = m.get('PhysicalSyncRead')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsReturned') is not None:
            self.rows_returned = m.get('RowsReturned')

        if m.get('Rt') is not None:
            self.rt = m.get('Rt')

        if m.get('ScanRows') is not None:
            self.scan_rows = m.get('ScanRows')

        if m.get('Scnt') is not None:
            self.scnt = m.get('Scnt')

        if m.get('Sql') is not None:
            self.sql = m.get('Sql')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('UpdateRows') is not None:
            self.update_rows = m.get('UpdateRows')

        if m.get('User') is not None:
            self.user = m.get('User')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSlowLogRecordsResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSlowLogRecordsResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # DBLogRecords<SlowLogItem>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSlowLogRecordsResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSlowLogRecordsResponseBodyData(DaraModel):
    def __init__(
        self,
        db_instance_id: int = None,
        db_instance_name: str = None,
        end_time: str = None,
        items_numbers: int = None,
        logs: List[main_models.DescribeSlowLogRecordsResponseBodyDataLogs] = None,
        max_records_per_page: int = None,
        node_id: str = None,
        page_numbers: int = None,
        start_time: str = None,
        total_records: int = None,
    ):
        self.db_instance_id = db_instance_id
        self.db_instance_name = db_instance_name
        self.end_time = end_time
        self.items_numbers = items_numbers
        self.logs = logs
        self.max_records_per_page = max_records_per_page
        self.node_id = node_id
        self.page_numbers = page_numbers
        self.start_time = start_time
        self.total_records = total_records

    def validate(self):
        if self.logs:
            for v1 in self.logs:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_instance_id is not None:
            result['DbInstanceId'] = self.db_instance_id

        if self.db_instance_name is not None:
            result['DbInstanceName'] = self.db_instance_name

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.items_numbers is not None:
            result['ItemsNumbers'] = self.items_numbers

        result['Logs'] = []
        if self.logs is not None:
            for k1 in self.logs:
                result['Logs'].append(k1.to_map() if k1 else None)

        if self.max_records_per_page is not None:
            result['MaxRecordsPerPage'] = self.max_records_per_page

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.page_numbers is not None:
            result['PageNumbers'] = self.page_numbers

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.total_records is not None:
            result['TotalRecords'] = self.total_records

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbInstanceId') is not None:
            self.db_instance_id = m.get('DbInstanceId')

        if m.get('DbInstanceName') is not None:
            self.db_instance_name = m.get('DbInstanceName')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('ItemsNumbers') is not None:
            self.items_numbers = m.get('ItemsNumbers')

        self.logs = []
        if m.get('Logs') is not None:
            for k1 in m.get('Logs'):
                temp_model = main_models.DescribeSlowLogRecordsResponseBodyDataLogs()
                self.logs.append(temp_model.from_map(k1))

        if m.get('MaxRecordsPerPage') is not None:
            self.max_records_per_page = m.get('MaxRecordsPerPage')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PageNumbers') is not None:
            self.page_numbers = m.get('PageNumbers')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('TotalRecords') is not None:
            self.total_records = m.get('TotalRecords')

        return self

class DescribeSlowLogRecordsResponseBodyDataLogs(DaraModel):
    def __init__(
        self,
        account_name: str = None,
        application_name: str = None,
        cputime: float = None,
        cputime_seconds: float = None,
        client_ip: str = None,
        cmd: str = None,
        command: str = None,
        dbname: str = None,
        db_id: str = None,
        db_instance_name: str = None,
        docs_examined: str = None,
        frows: int = None,
        host_address: str = None,
        iowrites: int = None,
        ins_name: str = None,
        keys_examined: str = None,
        last_rows_count_affected: int = None,
        lock_time: float = None,
        lock_time_seconds: float = None,
        logical_ioreads: int = None,
        namespace: str = None,
        node_id: str = None,
        op_type: str = None,
        origin_time: str = None,
        physical_ioreads: int = None,
        psql: str = None,
        query_id: str = None,
        query_start_time: str = None,
        query_time: int = None,
        query_time_seconds: float = None,
        request_size: int = None,
        response_size: int = None,
        return_item_numbers: str = None,
        return_num: str = None,
        rows: int = None,
        rows_count_affected: int = None,
        rows_examined: int = None,
        rows_sent: int = None,
        rt: int = None,
        sqltext: str = None,
        scheme: str = None,
        scnt: int = None,
        sql_id: str = None,
        sql_tag: main_models.DescribeSlowLogRecordsResponseBodyDataLogsSqlTag = None,
        sql_type: str = None,
        sub_instance_id: str = None,
        table_name: str = None,
        template_id: str = None,
        thread_id: str = None,
        timestamp: int = None,
        trace_id: str = None,
    ):
        self.account_name = account_name
        self.application_name = application_name
        self.cputime = cputime
        self.cputime_seconds = cputime_seconds
        self.client_ip = client_ip
        self.cmd = cmd
        self.command = command
        self.dbname = dbname
        self.db_id = db_id
        self.db_instance_name = db_instance_name
        self.docs_examined = docs_examined
        self.frows = frows
        self.host_address = host_address
        self.iowrites = iowrites
        self.ins_name = ins_name
        self.keys_examined = keys_examined
        self.last_rows_count_affected = last_rows_count_affected
        self.lock_time = lock_time
        self.lock_time_seconds = lock_time_seconds
        self.logical_ioreads = logical_ioreads
        self.namespace = namespace
        self.node_id = node_id
        self.op_type = op_type
        self.origin_time = origin_time
        self.physical_ioreads = physical_ioreads
        self.psql = psql
        self.query_id = query_id
        self.query_start_time = query_start_time
        self.query_time = query_time
        self.query_time_seconds = query_time_seconds
        self.request_size = request_size
        self.response_size = response_size
        self.return_item_numbers = return_item_numbers
        self.return_num = return_num
        self.rows = rows
        self.rows_count_affected = rows_count_affected
        self.rows_examined = rows_examined
        self.rows_sent = rows_sent
        self.rt = rt
        self.sqltext = sqltext
        self.scheme = scheme
        self.scnt = scnt
        self.sql_id = sql_id
        self.sql_tag = sql_tag
        self.sql_type = sql_type
        self.sub_instance_id = sub_instance_id
        self.table_name = table_name
        self.template_id = template_id
        self.thread_id = thread_id
        self.timestamp = timestamp
        self.trace_id = trace_id

    def validate(self):
        if self.sql_tag:
            self.sql_tag.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_name is not None:
            result['AccountName'] = self.account_name

        if self.application_name is not None:
            result['ApplicationName'] = self.application_name

        if self.cputime is not None:
            result['CPUTime'] = self.cputime

        if self.cputime_seconds is not None:
            result['CPUTimeSeconds'] = self.cputime_seconds

        if self.client_ip is not None:
            result['ClientIp'] = self.client_ip

        if self.cmd is not None:
            result['Cmd'] = self.cmd

        if self.command is not None:
            result['Command'] = self.command

        if self.dbname is not None:
            result['DBName'] = self.dbname

        if self.db_id is not None:
            result['DbId'] = self.db_id

        if self.db_instance_name is not None:
            result['DbInstanceName'] = self.db_instance_name

        if self.docs_examined is not None:
            result['DocsExamined'] = self.docs_examined

        if self.frows is not None:
            result['Frows'] = self.frows

        if self.host_address is not None:
            result['HostAddress'] = self.host_address

        if self.iowrites is not None:
            result['IOWrites'] = self.iowrites

        if self.ins_name is not None:
            result['InsName'] = self.ins_name

        if self.keys_examined is not None:
            result['KeysExamined'] = self.keys_examined

        if self.last_rows_count_affected is not None:
            result['LastRowsCountAffected'] = self.last_rows_count_affected

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.lock_time_seconds is not None:
            result['LockTimeSeconds'] = self.lock_time_seconds

        if self.logical_ioreads is not None:
            result['LogicalIOReads'] = self.logical_ioreads

        if self.namespace is not None:
            result['Namespace'] = self.namespace

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.op_type is not None:
            result['OpType'] = self.op_type

        if self.origin_time is not None:
            result['OriginTime'] = self.origin_time

        if self.physical_ioreads is not None:
            result['PhysicalIOReads'] = self.physical_ioreads

        if self.psql is not None:
            result['Psql'] = self.psql

        if self.query_id is not None:
            result['QueryId'] = self.query_id

        if self.query_start_time is not None:
            result['QueryStartTime'] = self.query_start_time

        if self.query_time is not None:
            result['QueryTime'] = self.query_time

        if self.query_time_seconds is not None:
            result['QueryTimeSeconds'] = self.query_time_seconds

        if self.request_size is not None:
            result['RequestSize'] = self.request_size

        if self.response_size is not None:
            result['ResponseSize'] = self.response_size

        if self.return_item_numbers is not None:
            result['ReturnItemNumbers'] = self.return_item_numbers

        if self.return_num is not None:
            result['ReturnNum'] = self.return_num

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.rows_count_affected is not None:
            result['RowsCountAffected'] = self.rows_count_affected

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.rt is not None:
            result['Rt'] = self.rt

        if self.sqltext is not None:
            result['SQLText'] = self.sqltext

        if self.scheme is not None:
            result['Scheme'] = self.scheme

        if self.scnt is not None:
            result['Scnt'] = self.scnt

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_tag is not None:
            result['SqlTag'] = self.sql_tag.to_map()

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.sub_instance_id is not None:
            result['SubInstanceId'] = self.sub_instance_id

        if self.table_name is not None:
            result['TableName'] = self.table_name

        if self.template_id is not None:
            result['TemplateId'] = self.template_id

        if self.thread_id is not None:
            result['ThreadId'] = self.thread_id

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.trace_id is not None:
            result['TraceId'] = self.trace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountName') is not None:
            self.account_name = m.get('AccountName')

        if m.get('ApplicationName') is not None:
            self.application_name = m.get('ApplicationName')

        if m.get('CPUTime') is not None:
            self.cputime = m.get('CPUTime')

        if m.get('CPUTimeSeconds') is not None:
            self.cputime_seconds = m.get('CPUTimeSeconds')

        if m.get('ClientIp') is not None:
            self.client_ip = m.get('ClientIp')

        if m.get('Cmd') is not None:
            self.cmd = m.get('Cmd')

        if m.get('Command') is not None:
            self.command = m.get('Command')

        if m.get('DBName') is not None:
            self.dbname = m.get('DBName')

        if m.get('DbId') is not None:
            self.db_id = m.get('DbId')

        if m.get('DbInstanceName') is not None:
            self.db_instance_name = m.get('DbInstanceName')

        if m.get('DocsExamined') is not None:
            self.docs_examined = m.get('DocsExamined')

        if m.get('Frows') is not None:
            self.frows = m.get('Frows')

        if m.get('HostAddress') is not None:
            self.host_address = m.get('HostAddress')

        if m.get('IOWrites') is not None:
            self.iowrites = m.get('IOWrites')

        if m.get('InsName') is not None:
            self.ins_name = m.get('InsName')

        if m.get('KeysExamined') is not None:
            self.keys_examined = m.get('KeysExamined')

        if m.get('LastRowsCountAffected') is not None:
            self.last_rows_count_affected = m.get('LastRowsCountAffected')

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('LockTimeSeconds') is not None:
            self.lock_time_seconds = m.get('LockTimeSeconds')

        if m.get('LogicalIOReads') is not None:
            self.logical_ioreads = m.get('LogicalIOReads')

        if m.get('Namespace') is not None:
            self.namespace = m.get('Namespace')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OpType') is not None:
            self.op_type = m.get('OpType')

        if m.get('OriginTime') is not None:
            self.origin_time = m.get('OriginTime')

        if m.get('PhysicalIOReads') is not None:
            self.physical_ioreads = m.get('PhysicalIOReads')

        if m.get('Psql') is not None:
            self.psql = m.get('Psql')

        if m.get('QueryId') is not None:
            self.query_id = m.get('QueryId')

        if m.get('QueryStartTime') is not None:
            self.query_start_time = m.get('QueryStartTime')

        if m.get('QueryTime') is not None:
            self.query_time = m.get('QueryTime')

        if m.get('QueryTimeSeconds') is not None:
            self.query_time_seconds = m.get('QueryTimeSeconds')

        if m.get('RequestSize') is not None:
            self.request_size = m.get('RequestSize')

        if m.get('ResponseSize') is not None:
            self.response_size = m.get('ResponseSize')

        if m.get('ReturnItemNumbers') is not None:
            self.return_item_numbers = m.get('ReturnItemNumbers')

        if m.get('ReturnNum') is not None:
            self.return_num = m.get('ReturnNum')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('RowsCountAffected') is not None:
            self.rows_count_affected = m.get('RowsCountAffected')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('Rt') is not None:
            self.rt = m.get('Rt')

        if m.get('SQLText') is not None:
            self.sqltext = m.get('SQLText')

        if m.get('Scheme') is not None:
            self.scheme = m.get('Scheme')

        if m.get('Scnt') is not None:
            self.scnt = m.get('Scnt')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlTag') is not None:
            temp_model = main_models.DescribeSlowLogRecordsResponseBodyDataLogsSqlTag()
            self.sql_tag = temp_model.from_map(m.get('SqlTag'))

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('SubInstanceId') is not None:
            self.sub_instance_id = m.get('SubInstanceId')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        if m.get('TemplateId') is not None:
            self.template_id = m.get('TemplateId')

        if m.get('ThreadId') is not None:
            self.thread_id = m.get('ThreadId')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('TraceId') is not None:
            self.trace_id = m.get('TraceId')

        return self

class DescribeSlowLogRecordsResponseBodyDataLogsSqlTag(DaraModel):
    def __init__(
        self,
        comments: str = None,
        sql_id: str = None,
        tags: str = None,
    ):
        self.comments = comments
        # sqlid。
        self.sql_id = sql_id
        self.tags = tags

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.comments is not None:
            result['Comments'] = self.comments

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.tags is not None:
            result['Tags'] = self.tags

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Comments') is not None:
            self.comments = m.get('Comments')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('Tags') is not None:
            self.tags = m.get('Tags')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateRequestDiagnosisRequest(DaraModel):
    def __init__(
        self,
        database: str = None,
        instance_id: str = None,
        node_id: str = None,
        sql: str = None,
    ):
        # The name of the database.
        # 
        # This parameter is required.
        self.database = database
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  This parameter must be specified for PolarDB for MySQL, PolarDB for PostgreSQL (Compatible with Oracle), and ApsaraDB for MongoDB instances.
        self.node_id = node_id
        # The SQL statement that you want to diagnose.
        # 
        # This parameter is required.
        self.sql = sql

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.database is not None:
            result['Database'] = self.database

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.sql is not None:
            result['Sql'] = self.sql

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Database') is not None:
            self.database = m.get('Database')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Sql') is not None:
            self.sql = m.get('Sql')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any

from darabonba.model import DaraModel

class DataValue(DaraModel):
    def __init__(
        self,
        timestamp: str = None,
        value: Any = None,
    ):
        # The timestamp. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The value of the metric.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateKillInstanceSessionTaskRequest(DaraModel):
    def __init__(
        self,
        db_user: str = None,
        db_user_password: str = None,
        ignored_users: str = None,
        instance_id: str = None,
        kill_all_sessions: bool = None,
        node_id: str = None,
        session_ids: str = None,
    ):
        # The database account that has the permissions to terminate sessions.
        # 
        # This parameter is required.
        self.db_user = db_user
        # The password of the database account.
        # 
        # This parameter is required.
        self.db_user_password = db_user_password
        # The account whose sessions do not need to be terminated.
        # 
        # >  Set this parameter to a JSON array. Separate database accounts with commas (,). Example: [\\"Database account 1\\",\\"Database account 2\\"].
        self.ignored_users = ignored_users
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # Specifies whether to terminate all sessions.
        # 
        # *   **true**
        # *   **false**
        # 
        # >  If you set this parameter to **true**, sessions of the accounts that are specified by **IgnoredUsers**, sessions of internal O\\&M accounts of Alibaba Cloud, and **Binlog Dump** sessions are not terminated.
        # 
        # This parameter is required.
        self.kill_all_sessions = kill_all_sessions
        # The node ID.
        # 
        # >  This parameter must be specified if the database instance is a PolarDB for MySQL cluster. If you do not specify a node ID and set **KillAllSessions** to **true**, the system traverses all nodes in the PolarDB for MySQL cluster and terminates the active sessions on each node.
        self.node_id = node_id
        # The IDs of sessions that need to be terminated.
        # 
        # >  Set this parameter to a JSON array. Separate session IDs with commas (,). Example: [\\"Session ID1\\",\\"Session ID2\\"]. If **KillAllSessions** is set to **true**, this parameter does not take effect.
        self.session_ids = session_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_user is not None:
            result['DbUser'] = self.db_user

        if self.db_user_password is not None:
            result['DbUserPassword'] = self.db_user_password

        if self.ignored_users is not None:
            result['IgnoredUsers'] = self.ignored_users

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.kill_all_sessions is not None:
            result['KillAllSessions'] = self.kill_all_sessions

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.session_ids is not None:
            result['SessionIds'] = self.session_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbUser') is not None:
            self.db_user = m.get('DbUser')

        if m.get('DbUserPassword') is not None:
            self.db_user_password = m.get('DbUserPassword')

        if m.get('IgnoredUsers') is not None:
            self.ignored_users = m.get('IgnoredUsers')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('KillAllSessions') is not None:
            self.kill_all_sessions = m.get('KillAllSessions')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('SessionIds') is not None:
            self.session_ids = m.get('SessionIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetDeadLockHistoryRequest(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        instance_id: str = None,
        node_id: str = None,
        page_no: int = None,
        page_size: int = None,
        source: str = None,
        start_time: int = None,
    ):
        # This parameter is required.
        self.end_time = end_time
        # This parameter is required.
        self.instance_id = instance_id
        self.node_id = node_id
        self.page_no = page_no
        self.page_size = page_size
        self.source = source
        # This parameter is required.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.source is not None:
            result['Source'] = self.source

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Source') is not None:
            self.source = m.get('Source')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetRunningSqlConcurrencyControlRulesResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetRunningSqlConcurrencyControlRulesResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, Successful is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetRunningSqlConcurrencyControlRulesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetRunningSqlConcurrencyControlRulesResponseBodyData(DaraModel):
    def __init__(
        self,
        list: main_models.GetRunningSqlConcurrencyControlRulesResponseBodyDataList = None,
        total: int = None,
    ):
        self.list = list
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            self.list.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.list is not None:
            result['List'] = self.list.to_map()

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('List') is not None:
            temp_model = main_models.GetRunningSqlConcurrencyControlRulesResponseBodyDataList()
            self.list = temp_model.from_map(m.get('List'))

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetRunningSqlConcurrencyControlRulesResponseBodyDataList(DaraModel):
    def __init__(
        self,
        running_rules: List[main_models.GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules] = None,
    ):
        self.running_rules = running_rules

    def validate(self):
        if self.running_rules:
            for v1 in self.running_rules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['runningRules'] = []
        if self.running_rules is not None:
            for k1 in self.running_rules:
                result['runningRules'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.running_rules = []
        if m.get('runningRules') is not None:
            for k1 in m.get('runningRules'):
                temp_model = main_models.GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules()
                self.running_rules.append(temp_model.from_map(k1))

        return self

class GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules(DaraModel):
    def __init__(
        self,
        concurrency_control_time: int = None,
        instance_id: str = None,
        item_id: int = None,
        keywords_hash: str = None,
        max_concurrency: str = None,
        sql_keywords: str = None,
        sql_type: str = None,
        start_time: int = None,
        status: str = None,
        user_id: str = None,
    ):
        self.concurrency_control_time = concurrency_control_time
        self.instance_id = instance_id
        self.item_id = item_id
        self.keywords_hash = keywords_hash
        self.max_concurrency = max_concurrency
        self.sql_keywords = sql_keywords
        self.sql_type = sql_type
        self.start_time = start_time
        self.status = status
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.concurrency_control_time is not None:
            result['ConcurrencyControlTime'] = self.concurrency_control_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.item_id is not None:
            result['ItemId'] = self.item_id

        if self.keywords_hash is not None:
            result['KeywordsHash'] = self.keywords_hash

        if self.max_concurrency is not None:
            result['MaxConcurrency'] = self.max_concurrency

        if self.sql_keywords is not None:
            result['SqlKeywords'] = self.sql_keywords

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.status is not None:
            result['Status'] = self.status

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConcurrencyControlTime') is not None:
            self.concurrency_control_time = m.get('ConcurrencyControlTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('ItemId') is not None:
            self.item_id = m.get('ItemId')

        if m.get('KeywordsHash') is not None:
            self.keywords_hash = m.get('KeywordsHash')

        if m.get('MaxConcurrency') is not None:
            self.max_concurrency = m.get('MaxConcurrency')

        if m.get('SqlKeywords') is not None:
            self.sql_keywords = m.get('SqlKeywords')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetFullRequestStatResultByInstanceIdRequest(DaraModel):
    def __init__(
        self,
        asc: bool = None,
        db_name: str = None,
        end: int = None,
        instance_id: str = None,
        keyword: str = None,
        node_id: str = None,
        order_by: str = None,
        origin_host: str = None,
        page_no: int = None,
        page_size: int = None,
        role: str = None,
        sql_id: str = None,
        sql_type: str = None,
        start: int = None,
        user_id: str = None,
    ):
        # Specifies whether to sort the results in ascending order. By default, the results are not sorted in ascending order.
        self.asc = asc
        # The name of the database.
        self.db_name = db_name
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time. The interval cannot exceed one day.
        # 
        # This parameter is required.
        self.end = end
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The keywords that are used for query.
        self.keyword = keyword
        # The node ID.
        # 
        # >  You must specify the node ID if your database instance is a PolarDB for MySQL cluster.
        self.node_id = node_id
        # The field by which to sort the returned entries. Default value: **count**. Valid values:
        # 
        # *   **count**: the number of executions.
        # *   **avgRt**: the average execution duration.
        # *   **rtRate**: the execution duration percentage.
        # *   **rowsExamined**: the total number of scanned rows.
        # *   **avgRowsExamined**: the average number of scanned rows.
        # *   **avgRowsReturned**: the average number of returned rows.
        self.order_by = order_by
        # The IP address of the client that executes the SQL statement.
        # 
        # >  This parameter is optional. If this parameter is specified, the full request statistics of the specified IP address are collected. If this parameter is left empty, the full request statistics of the entire database instance are collected.
        self.origin_host = origin_host
        # The page number. Pages start from page 1. Default value: 1.
        # 
        # This parameter is required.
        self.page_no = page_no
        # The number of entries per page. Default value: 20.
        # 
        # This parameter is required.
        self.page_size = page_size
        # The role of the node in the PolarDB-X 2.0 instance. Valid values:
        # 
        # *   **polarx_cn**: compute node.
        # *   **polarx_dn**: data node.
        self.role = role
        # The SQL ID.
        # 
        # >  If this parameter is specified, the full request statistics of the specified SQL query are collected. If this parameter is left empty, the full request statistics of the entire database instance are collected.
        self.sql_id = sql_id
        # The type of the SQL statement. Valid values: **SELECT**, **INSERT**, **UPDATE**, **DELETE**, **LOGIN**, **LOGOUT**, **MERGE**, **ALTER**, **CREATEINDEX**, **DROPINDEX**, **CREATE**, **DROP**, **SET**, **DESC**, **REPLACE**, **CALL**, **BEGIN**, **DESCRIBE**, **ROLLBACK**, **FLUSH**, **USE**, **SHOW**, **START**, **COMMIT**, and **RENAME**.
        # 
        # >  If your database instance is an ApsaraDB RDS for MySQL instance, a PolarDB for MySQL cluster, or a PolarDB-X 2.0 instance, the statistics can be collected based on the SQL statement type.
        self.sql_type = sql_type
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The start time can be up to 90 days earlier than the current time.
        # 
        # This parameter is required.
        self.start = start
        # The ID of the Alibaba Cloud account that was used to create the database instance.
        # 
        # >  This parameter is optional. The system can automatically obtain the Alibaba Cloud account ID based on the value of InstanceId when you call the GetFullRequestOriginStatByInstanceId operation.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.asc is not None:
            result['Asc'] = self.asc

        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.end is not None:
            result['End'] = self.end

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.order_by is not None:
            result['OrderBy'] = self.order_by

        if self.origin_host is not None:
            result['OriginHost'] = self.origin_host

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.role is not None:
            result['Role'] = self.role

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.start is not None:
            result['Start'] = self.start

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Asc') is not None:
            self.asc = m.get('Asc')

        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('End') is not None:
            self.end = m.get('End')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OrderBy') is not None:
            self.order_by = m.get('OrderBy')

        if m.get('OriginHost') is not None:
            self.origin_host = m.get('OriginHost')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Role') is not None:
            self.role = m.get('Role')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('Start') is not None:
            self.start = m.get('Start')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetYaoChiAgentRequest(DaraModel):
    def __init__(
        self,
        extra_info: str = None,
        query: str = None,
        session_id: str = None,
        source: str = None,
    ):
        self.extra_info = extra_info
        # This parameter is required.
        self.query = query
        self.session_id = session_id
        self.source = source

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extra_info is not None:
            result['ExtraInfo'] = self.extra_info

        if self.query is not None:
            result['Query'] = self.query

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        if self.source is not None:
            result['Source'] = self.source

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ExtraInfo') is not None:
            self.extra_info = m.get('ExtraInfo')

        if m.get('Query') is not None:
            self.query = m.get('Query')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        if m.get('Source') is not None:
            self.source = m.get('Source')

        return self

